@@ -90,10 +90,14 @@ class ClickHouseWriter(ManagedResource):
 
         # one client per thread to avoid session contention
         self._tlocal = threading.local()
+        ow = self.overwrite
+        if ow:
+            self._command(f"DROP TABLE IF EXISTS {self._ident(self.table)}")
+            self.logger.info(f"Dropped table {self.table} (overwrite=True)")
 
     # ------------- public -------------
 
-    def save_to_clickhouse(self, df: dd.DataFrame, *, overwrite: Optional[bool] = None) -> None:
+    def save_to_clickhouse(self, df: dd.DataFrame) -> None:
         """
         Persist a Dask DataFrame into ClickHouse.
 
@@ -118,15 +122,10 @@ class ClickHouseWriter(ManagedResource):
         )
 
         # (re)create table
-        ow = self.overwrite if overwrite is None else bool(overwrite)
         dtypes = df._meta_nonempty.dtypes  # metadata-only types (no compute)
         schema_sql = self._generate_clickhouse_schema(dtypes)
         engine_sql = self._default_engine_sql() if not self.engine else self.engine
 
-        if ow:
-            self._command(f"DROP TABLE IF EXISTS {self._ident(self.table)}")
-            self.logger.info(f"Dropped table {self.table} (overwrite=True)")
-
         create_sql = f"CREATE TABLE IF NOT EXISTS {self._ident(self.table)} ({schema_sql}) {engine_sql}"
         self._command(create_sql)
         self.logger.info(f"Ensured table {self.table} exists")
